@@ -450,7 +450,7 @@ void cluster_dist_add_val(redisCluster *c, clusterKeyVal *kv, zval *z_val
     // Serialize our value
     val_free = redis_pack(c->flags, z_val, &val, &val_len);
 
-    // Attach it to the provided keyval entry
+    // Attach it to the provied keyval entry
     kv->val = val;
     kv->val_len = val_len;
     kv->val_free = val_free;
@@ -468,7 +468,7 @@ void cluster_multi_add(clusterMultiCmd *mc, char *data, int data_len) {
     redis_cmd_append_sstr(&(mc->args), data, data_len);
 }
 
-/* Finalize a clusterMultiCmd by constructing the whole thing */
+/* Finalize a clusterMutliCmd by constructing the whole thing */
 void cluster_multi_fini(clusterMultiCmd *mc) {
     mc->cmd.len = 0;
     redis_cmd_init_sstr(&(mc->cmd), mc->argc, mc->kw, mc->kw_len);
@@ -709,7 +709,7 @@ static int cluster_map_slots(redisCluster *c, clusterReply *r) {
             master = cluster_node_create(c, host, hlen, port, low, 0);
             zend_hash_str_update_ptr(c->nodes, key, klen, master);
 
-            // Attach slaves first time we encounter a given master in order to avoid registering the slaves multiple times
+            // Attach slaves first time we encounter a given master in order to avoid regitering the slaves multiple times
             for (j = 3; j< r2->elements; j++) {
                 r3 = r2->element[j];
                 if (!VALIDATE_SLOTS_INNER(r3)) {
@@ -833,7 +833,7 @@ PHP_REDIS_API redisCluster *cluster_create(double timeout, double read_timeout,
     c->err = NULL;
 
     /* Set up our waitms based on timeout */
-    c->waitms  = (long)(1000 * (timeout + read_timeout));
+    c->waitms  = (long)(1000 * timeout);
 
     /* Allocate our seeds hash table */
     ALLOC_HASHTABLE(c->seeds);
@@ -1151,7 +1151,7 @@ static int cluster_set_redirection(redisCluster* c, char *msg, int moved)
  * redirection, parsing out slot host and port so the caller can take
  * appropriate action.
  *
- * In the case of a non MOVED/ASK error, we will set our cluster error
+ * In the case of a non MOVED/ASK error, we wlll set our cluster error
  * condition so GetLastError can be queried by the client.
  *
  * This function will return -1 on a critical error (e.g. parse/communication
@@ -1910,15 +1910,15 @@ PHP_REDIS_API void cluster_type_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster
     // Switch on the type
     if (strncmp (c->line_reply, "string", 6) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_STRING);
-    } else if (strncmp(c->line_reply, ZEND_STRL("set")) == 0) {
+    } else if (strncmp(c->line_reply, "set", 3) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_SET);
-    } else if (strncmp(c->line_reply, ZEND_STRL("list")) == 0) {
+    } else if (strncmp(c->line_reply, "list", 4) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_LIST);
-    } else if (strncmp(c->line_reply, ZEND_STRL("hash")) == 0) {
+    } else if (strncmp(c->line_reply, "hash", 4) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_HASH);
-    } else if (strncmp(c->line_reply, ZEND_STRL("zset")) == 0) {
+    } else if (strncmp(c->line_reply, "zset", 4) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_ZSET);
-    } else if (strncmp(c->line_reply, ZEND_STRL("stream")) == 0) {
+    } else if (strncmp(c->line_reply, "stream", 6) == 0) {
         CLUSTER_RETURN_LONG(c, REDIS_STREAM);
     } else {
         CLUSTER_RETURN_LONG(c, REDIS_NOT_FOUND);
@@ -1977,8 +1977,8 @@ PHP_REDIS_API void cluster_sub_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster *
         }
 
         // Make sure we have a message or pmessage
-        if (!strncmp(Z_STRVAL_P(z_type), ZEND_STRL("message")) ||
-            !strncmp(Z_STRVAL_P(z_type), ZEND_STRL("pmessage"))
+        if (!strncmp(Z_STRVAL_P(z_type), "message", 7) ||
+            !strncmp(Z_STRVAL_P(z_type), "pmessage", 8)
         ) {
             is_pmsg = *Z_STRVAL_P(z_type) == 'p';
         } else {
@@ -2279,9 +2279,8 @@ PHP_REDIS_API void cluster_gen_mbulk_resp(INTERNAL_FUNCTION_PARAMETERS,
 }
 
 /* HSCAN, SSCAN, ZSCAN */
-PHP_REDIS_API int
-cluster_scan_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster *c,
-                  REDIS_SCAN_TYPE type, uint64_t *cursor)
+PHP_REDIS_API int cluster_scan_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster *c,
+                              REDIS_SCAN_TYPE type, long *it)
 {
     char *pit;
 
@@ -2305,11 +2304,12 @@ cluster_scan_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster *c,
     }
 
     // Push the new iterator value to our caller
-    *cursor = strtoull(pit, NULL, 10);
+    *it = atol(pit);
     efree(pit);
 
     // We'll need another MULTIBULK response for the payload
-    if (cluster_check_response(c, &c->reply_type) < 0) {
+    if (cluster_check_response(c, &c->reply_type) < 0)
+    {
         return FAILURE;
     }
 
@@ -2995,7 +2995,7 @@ static zend_string **get_valid_seeds(HashTable *input, uint32_t *nseeds) {
         }
 
         /* Add as a key to avoid duplicates */
-        zend_hash_str_add_empty_element(valid, Z_STRVAL_P(z_seed), Z_STRLEN_P(z_seed));
+        zend_hash_str_update_ptr(valid, Z_STRVAL_P(z_seed), Z_STRLEN_P(z_seed), NULL);
     } ZEND_HASH_FOREACH_END();
 
     /* We need at least one valid seed */
