@@ -116,7 +116,7 @@
     mc->args.len = 0; \
     mc->argc     = 0; \
 
-/* Initialize a clusterMultiCmd with a keyword and length */
+/* Initialzie a clusterMultiCmd with a keyword and length */
 #define CLUSTER_MULTI_INIT(mc, keyword, keyword_len) \
     mc.kw     = keyword; \
     mc.kw_len = keyword_len; \
@@ -264,8 +264,6 @@ struct clusterFoldItem {
 
     /* Next item in our list */
     struct clusterFoldItem *next;
-
-    uint8_t flags;
 };
 
 /* Key and value container, with info if they need freeing */
@@ -392,7 +390,6 @@ PHP_REDIS_API char **cluster_sock_read_multibulk_reply(RedisSock *redis_sock, in
 
 PHP_REDIS_API void cluster_cache_store(zend_string *hash, HashTable *nodes);
 PHP_REDIS_API redisCachedCluster *cluster_cache_load(zend_string *hash);
-void cluster_cache_clear(redisCluster *c);
 
 /*
  * Redis Cluster response handlers.  Our response handlers generally take the
@@ -491,7 +488,7 @@ PHP_REDIS_API void cluster_msetnx_resp(INTERNAL_FUNCTION_PARAMETERS,
 
 /* Response handler for ZSCAN, SSCAN, and HSCAN */
 PHP_REDIS_API int cluster_scan_resp(INTERNAL_FUNCTION_PARAMETERS,
-    redisCluster *c, REDIS_SCAN_TYPE type, uint64_t *cursor);
+    redisCluster *c, REDIS_SCAN_TYPE type, long *it);
 
 /* INFO response handler */
 PHP_REDIS_API void cluster_info_resp(INTERNAL_FUNCTION_PARAMETERS,
